#!/usr/bin/env bash

test_description='Check correctness of oggdec output.

Executes para_filter -f oggdec on the test files provided by the test
suite and compares the output against the output of the reference
implementation.'

. ${0%/*}/test-lib.sh

test_require_objects "oggdec_filter"
missing_objects="$result"

test_require_executables oggdec shasum
missing_executables="$result"

get_audio_file_paths ogg
oggs="$result"

for ogg in $oggs; do
	if [[ -n "$missing_objects" ]]; then
		test_skip "${ogg##*/}" "missing object(s): $missing_objects"
		continue
	fi
	if [[ -n "$missing_executables" ]]; then
		test_skip "${ogg##*/}" \
			"missing executables(s): $missing_executables"
		continue
	fi
	test_expect_success "${ogg##*/}" "
		$PARA_FILTER -f oggdec < $ogg | shasum > filter.sha &&
		oggdec --quiet --raw --output - -  < $ogg | shasum > oggdec.sha &&
		diff -u filter.sha oggdec.sha
	"
done
test_done
